import * as React from 'react';
import type { TLShape, TLPage, TLPageState, TLCallbacks, TLTheme, TLBounds, TLBinding } from '../../types';
import { Inputs } from '../../inputs';
import type { TLShapeUtil, TLSnapLine, TLUsers } from '../../index';
export interface RendererProps<T extends TLShape, E extends Element = any, M = any> extends Partial<TLCallbacks<T>> {
    /**
     * (optional) A unique id to be applied to the renderer element, used to scope styles.
     */
    id?: string;
    /**
     * (optional) A ref for the renderer's container element, used for scoping event handlers.
     */
    containerRef?: React.RefObject<HTMLElement>;
    /**
     * An object containing instances of your shape classes.
     */
    shapeUtils: Record<T['type'], TLShapeUtil<T, E, M>>;
    /**
     * The current page, containing shapes and bindings.
     */
    page: TLPage<T, TLBinding>;
    /**
     * The current page state.
     */
    pageState: TLPageState;
    /**
     * (optional) The current users to render.
     */
    users?: TLUsers<T>;
    /**
     * (optional) The current snap lines to render.
     */
    snapLines?: TLSnapLine[];
    /**
     * (optional) The current user's id, used to identify the user.
     */
    userId?: string;
    /**
     * (optional) An object of custom theme colors.
     */
    theme?: Partial<TLTheme>;
    /**
     * (optional) When true, the renderer will not show the bounds for selected objects.
     */
    hideBounds?: boolean;
    /**
     * (optional) When true, the renderer will not show the handles of shapes with handles.
     */
    hideHandles?: boolean;
    /**
     * (optional) When true, the renderer will not show indicators for selected or
     * hovered objects,
     */
    hideIndicators?: boolean;
    /**
     * (optional) hen true, the renderer will ignore all inputs that were not made
     * by a stylus or pen-type device.
     */
    isPenMode?: boolean;
    /**
     * (optional) An object of custom options that should be passed to rendered shapes.
     */
    meta?: M;
    /**
     * (optional) A callback that receives the renderer's inputs manager.
     */
    onMount?: (inputs: Inputs) => void;
    /**
     * (optional) A callback that is fired when the editor's client bounding box changes.
     */
    onBoundsChange?: (bounds: TLBounds) => void;
}
/**
 * The Renderer component is the main component of the library. It
 * accepts the current `page`, the `shapeUtils` needed to interpret
 * and render the shapes and bindings on the `page`, and the current
 * `pageState`.
 * @param props
 * @returns
 */
export declare function Renderer<T extends TLShape, E extends Element, M extends Record<string, unknown>>({ id, shapeUtils, page, pageState, users, userId, theme, meta, snapLines, containerRef, hideHandles, hideIndicators, hideBounds, onMount, ...rest }: RendererProps<T, E, M>): JSX.Element;
//# sourceMappingURL=renderer.d.ts.map